@@ -3,8 +3,11 @@ package cmdruntime
 import (
 	"errors"
 	"runtime"
+	godebug "runtime/debug"
 	"sort"
+	"strings"
 
+	"github.com/lmorg/murex/app"
 	"github.com/lmorg/murex/builtins/core/open"
 	"github.com/lmorg/murex/builtins/events"
 	"github.com/lmorg/murex/config/defaults"
@@ -21,6 +24,7 @@ import (
 	"github.com/lmorg/murex/utils/cache"
 	cdcache "github.com/lmorg/murex/utils/cd/cache"
 	"github.com/lmorg/murex/utils/envvars"
+	"github.com/lmorg/murex/utils/humannumbers"
 	"github.com/lmorg/murex/utils/json"
 )
 
@@ -66,6 +70,7 @@ const (
 	fCacheDbEnabled     = "--cache-db-enabled"
 	fCacheDbPath        = "--cache-db-path"
 	fGoGarbageCollect   = "--go-gc"
+	fAbout              = "--about"
 	fHelp               = "--help"
 )
 
@@ -111,6 +116,7 @@ var flags = map[string]string{
 	fCacheDbEnabled:     types.Boolean,
 	fCacheDbPath:        types.Boolean,
 	fGoGarbageCollect:   types.Boolean,
+	fAbout:              types.Boolean,
 	fHelp:               types.Boolean,
 }
 
@@ -261,10 +267,17 @@ func cmdRuntime(p *lang.Process) error {
 		case fCacheDbPath:
 			ret[flag[2:]] = cache.DbPath()
 		case fGoGarbageCollect:
-			runtime.GC()
-			ret[fGoGarbageCollect] = "done"
+			//runtime.GC()
+			godebug.FreeOSMemory()
+			ret[flag[2:]] = "done"
+		case fAbout:
+			v := dumpAbout()
+			if v == nil {
+				return errors.New("unexpected error: reason unknown")
+			}
+			ret[flag[2:]] = v
 		case fHelp:
-			ret[fHelp[2:]] = Help()
+			ret[flag[2:]] = Help()
 		default:
 			return errors.New("unrecognized parameter: " + flag)
 		}
@@ -297,3 +310,47 @@ func dumpTestResults(p *lang.Process) interface{} {
 		"process": p.Tests.Results.Dump(),
 	}
 }
+
+func dumpAbout() any {
+	info, ok := godebug.ReadBuildInfo()
+	if !ok {
+		return nil
+	}
+
+	var mem runtime.MemStats
+	runtime.ReadMemStats(&mem)
+
+	m := map[string]any{
+		"GoVersion":    info.GoVersion,
+		"GitBranch":    app.Branch,
+		"SemVer":       app.Semver(),
+		"BuildDate":    app.BuildDate,
+		"DebugEnabled": debug.Enabled,
+		//"TestEnabled":  p.Scope.Tests != nil,
+		"NumCgoCalls": runtime.NumCgoCall(),
+		"NumRoutines": runtime.NumGoroutine(),
+		"NumCpus":     runtime.NumCPU(),
+	}
+
+	buildSettings := make(map[string]any)
+	for _, setting := range info.Settings {
+		if setting.Key == "-tags" || setting.Key == "DefaultGODEBUG" {
+			buildSettings[setting.Key] = sort.StringSlice(strings.Split(setting.Value, ","))
+		} else {
+			buildSettings[setting.Key] = setting.Value
+		}
+	}
+	m["BuildSettings"] = buildSettings
+
+	m["MemStats"] = map[string]any{
+		"Alloc":       humannumbers.Bytes(mem.Alloc),
+		"TotalAlloc":  humannumbers.Bytes(mem.TotalAlloc),
+		"Sys":         humannumbers.Bytes(mem.Sys),
+		"Mallocs":     mem.Mallocs,
+		"Frees":       mem.Frees,
+		"NumGC":       mem.NumGC,
+		"NumForcedGC": mem.NumForcedGC,
+	}
+
+	return m
+}
