@@ -9,6 +9,7 @@ import (
 	"github.com/lmorg/murex/builtins/pipes/streams"
 	"github.com/lmorg/murex/builtins/pipes/term"
 	"github.com/lmorg/murex/debug"
+	"github.com/lmorg/murex/lang/process"
 	"github.com/lmorg/murex/lang/runmode"
 	"github.com/lmorg/murex/lang/state"
 	"github.com/lmorg/murex/lang/types"
@@ -54,6 +55,9 @@ const (
 	// F_BACKGROUND this process will run in the background
 	F_BACKGROUND
 
+	// F_ASSIGN_JOBID will allow child functions to gain an %n job id for job control
+	F_ASSIGN_JOBID
+
 	// F_CREATE_STDIN will create a new stdin stdio.Io interface
 	F_CREATE_STDIN
 
@@ -97,6 +101,7 @@ const ForkSuffix = " (fork)"
 func (p *Process) Fork(flags int) *Fork {
 	fork := new(Fork)
 	fork.Process = new(Process)
+	fork.SystemProcess = process.NewSystemProcessStruct()
 	fork.SetTerminatedState(true)
 	fork.Forks = p.Forks
 	trace(fork.Process)
@@ -104,6 +109,7 @@ func (p *Process) Fork(flags int) *Fork {
 
 	fork.State.Set(state.MemAllocated)
 	fork.Background.Set(flags&F_BACKGROUND != 0 || p.Background.Get())
+	fork.HasJobId.Set(flags&F_ASSIGN_JOBID != 0 || p.HasJobId.Get())
 
 	fork.IsMethod = p.IsMethod
 	fork.OperatorLogicAnd = p.OperatorLogicAnd
