@@ -12,6 +12,7 @@ import (
 	"github.com/lmorg/murex/config/defaults"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/shell"
+	signalhandler "github.com/lmorg/murex/shell/signal_handler"
 	"github.com/lmorg/murex/utils/ansi"
 	"github.com/lmorg/murex/utils/readline"
 )
@@ -121,3 +122,8 @@ func wasmKeyPress() js.Func {
 		return promiseConstructor.New(handler)
 	})
 }
+
+func registerSignalHandlers(interactiveMode bool) {
+	signalhandler.Handlers = &signalhandler.SignalFunctionsT{}
+	signalhandler.EventLoop(interactiveMode)
+}
